.. fwdpy11 documentation master file, created by
   sphinx-quickstart on Mon Mar 20 12:22:19 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to fwdpy11's documentation!
===================================

.. toctree::
    :caption: Contents:

.. toctree::
    :caption: Miscellaneous notes
    :maxdepth: 1

    pages/conventions
    pages/changelog
    pages/deprecated
    pages/todo
    pages/pubs

.. toctree::
    :caption: Concepts
    :maxdepth: 2

    pages/definitions

.. toctree::
    :caption: Data Types
    :maxdepth: 2

    pages/types
    pages/rng
    pages/regions
    pages/model_params
    pages/recorders

.. toctree::
    :caption: Examples
    :maxdepth: 1

    examples/parallel_simulation
    examples/customgvalue
    examples/stateful_fitness
    examples/pickling
    examples/DataMatrix
    examples/qtrait
    examples/processingpops

.. toctree::
    :caption: Maximizing performance
    :maxdepth: 1

    performance/processingpops_np
    performance/UsingCython.ipynb
    performance/RecorderPerformance.ipynb

.. toctree::
    :caption: Advanced topics and examples
    :maxdepth: 1

    advanced/heritability
    advanced/manip
    advanced/mpi
    advanced/mpi2


.. toctree::
    :caption: Modules
    :maxdepth: 2

fwdpy11.fwdpy11_types
------------------------------
.. automodule:: fwdpy11.fwdpy11_types
    :members:
    :show-inheritance:

fwdpy11.fwdpp_types
------------------------------
.. automodule:: fwdpy11.fwdpp_types
    :members:
    :show-inheritance:

fwdpy11.fitness
------------------------------
.. automodule:: fwdpy11.fitness
    :members:
    :show-inheritance:

fwdpy11.trait_values
------------------------------
.. automodule:: fwdpy11.trait_values
    :members:
    :show-inheritance:

fwdpy11.sampling
------------------------------
.. automodule:: fwdpy11.sampling
    :members:
    :show-inheritance:

fwdpy11.regions
------------------------------
.. automodule:: fwdpy11.regions
    :members:
    :show-inheritance:

fwdpy11.model_params
------------------------------
.. automodule:: fwdpy11.model_params
    :members:
    :show-inheritance:

fwdpy11.temporal_samplers
------------------------------
.. automodule:: fwdpy11.temporal_samplers
    :members:
    :show-inheritance:

fwdpy11.wright_fisher
------------------------------
.. automodule:: fwdpy11.wright_fisher
    :members:
    :show-inheritance:

fwdpy11.wright_fisher_qtrait
------------------------------
.. automodule:: fwdpy11.wright_fisher_qtrait
    :members:
    :show-inheritance:

fwdpy11.dev
------------------------------
.. automodule:: fwdpy11.dev
    :members:
    :show-inheritance:

fwdpy11.multilocus
------------------------------
.. automodule:: fwdpy11.multilocus
    :members:
    :show-inheritance:

fwdpy11.util
------------------------------
.. automodule:: fwdpy11.util
    :members:
    :show-inheritance:

fwdpy11.python_genetic_values
------------------------------------------------------------
.. automodule:: fwdpy11.python_genetic_values
    :members:
    :show-inheritance:

fwdpy11.demography
------------------------------------------------------------
.. automodule:: fwdpy11.demography
    :members:
    :show-inheritance:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
